# jupyterlab_autoversion
Automatically version jupyter notebooks in JupyterLab

[![Build Status](https://dev.azure.com/tpaine154/jupyter/_apis/build/status/timkpaine.jupyterlab_autoversion?branchName=main)](https://dev.azure.com/tpaine154/jupyter/_build/latest?definitionId=16&branchName=main)
[![Coverage](https://img.shields.io/azure-devops/coverage/tpaine154/jupyter/16/main)](https://dev.azure.com/tpaine154/jupyter/_build?definitionId=16&_a=summary)
[![GitHub issues](https://img.shields.io/github/issues/timkpaine/jupyterlab_autoversion.svg)]()
[![PyPI](https://img.shields.io/pypi/l/jupyterlab_autoversion.svg)](https://pypi.python.org/pypi/jupyterlab_autoversion)
[![PyPI](https://img.shields.io/pypi/v/jupyterlab_autoversion.svg)](https://pypi.python.org/pypi/jupyterlab_autoversion)
[![npm](https://img.shields.io/npm/v/jupyterlab_autoversion.svg)](https://www.npmjs.com/package/jupyterlab_autoversion)


## Save every notebook revision
Enhanced checkpoints, versioned and persistent between restarts on every save

![](https://raw.githubusercontent.com/timkpaine/jupyterlab_autoversion/main/docs/example.gif)


## Install

```bash
pip install jupyterlab_autoversion
jupyter lab build
```


## Development

See [CONTRIBUTING.md](./CONTRIBUTING.md) for guidelines.


## License

This software is licensed under the Apache 2.0 license. See the
[LICENSE](LICENSE) file for details.
